BBBB BBBBBBBBBBBBBBBBBBBB
XXXXXX XXXXXXXXXXXX XXXXXXXXXXX FFFFFFFFFF XX
    XXXXXXX
XXXX
    BBB BBBBBB BB BBBBBBBBBBBBB
        XXXXXXXXX

    BBBBBB
XXXXX
XXXXXXXX
XXXXXXX
BBB BBB BB BBBBBBBBBB
    XXX XXXXXXXBBBBB BBBBBB BBBBBBXX
    BBB BBBBBB BB BBBBBBBBBBBBB
        XXXXBBBBBBBB BBB BBBBBBXXXXX
        BBBBBB
    XXXXX
BBBBBB
XXXXXXXX
XXXXXXXX